==> haskell-fdo-notify-0.3.1-912.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-fdo-notify.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 fdo-notify
version:              0.3.1
visibility:           public
id:                   fdo-notify-0.3.1-IPh2kcw5nAUGwUs3UNrhcI
key:                  fdo-notify-0.3.1-IPh2kcw5nAUGwUs3UNrhcI
license:              BSD-3-Clause
maintainer:           max.rabkin@gmail.com
author:               Max Rabkin
homepage:             http://bitbucket.org/taejo/fdo-notify/
synopsis:             Desktop Notifications client
description:
    A library for issuing notifications using FreeDesktop.org'\''s Desktop
    Notifications protcol. This protocol is supported by services such
    as Ubuntu'\''s NotifyOSD.

category:             Desktop
abi:                  e8220e5681f930559491e8e890a0213f
exposed:              True
exposed-modules:      DBus.Notify
import-dirs:          /usr/lib/ghc-9.6.6/site-local/fdo-notify-0.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/fdo-notify-0.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/fdo-notify-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fdo-notify
hs-libraries:         HSfdo-notify-0.3.1-IPh2kcw5nAUGwUs3UNrhcI
depends:
    base-4.18.2.1 containers-0.6.7 dbus-1.3.3-11fa9uMK72Y1CHWrLdB8AG

haddock-interfaces:   /usr/share/doc/haskell-fdo-notify/html/fdo-notify.haddock
haddock-html:         /usr/share/doc/haskell-fdo-notify/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fdo-notify-0.3.1-913-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-fdo-notify.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 fdo-notify
version:              0.3.1
visibility:           public
id:                   fdo-notify-0.3.1-LMQpMYpITEHHqZgy6suNhl
key:                  fdo-notify-0.3.1-LMQpMYpITEHHqZgy6suNhl
license:              BSD-3-Clause
maintainer:           max.rabkin@gmail.com
author:               Max Rabkin
homepage:             http://bitbucket.org/taejo/fdo-notify/
synopsis:             Desktop Notifications client
description:
    A library for issuing notifications using FreeDesktop.org'\''s Desktop
    Notifications protcol. This protocol is supported by services such
    as Ubuntu'\''s NotifyOSD.

category:             Desktop
abi:                  bb413266d8e5a02d6c2ff13ea4d8c171
exposed:              True
exposed-modules:      DBus.Notify
import-dirs:          /usr/lib/ghc-9.6.6/site-local/fdo-notify-0.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/fdo-notify-0.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/fdo-notify-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fdo-notify
hs-libraries:         HSfdo-notify-0.3.1-LMQpMYpITEHHqZgy6suNhl
depends:
    base-4.18.2.1 containers-0.6.7 dbus-1.3.3-I7Q67QGi2CK1IKKmdebsoN

haddock-interfaces:   /usr/share/doc/haskell-fdo-notify/html/fdo-notify.haddock
haddock-html:         /usr/share/doc/haskell-fdo-notify/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
